#!/usr/bin/env python
# -*- coding: iso-8859-1 -*-

"An OpenID login provider."

# Site map imports.

from WebStack.Generic import ContentType
from WebStack.Resources.OpenIDLogin import Authenticator
from WebStack.Resources.ResourceMap import MapResource
from WebStack.Resources.Selectors import EncodingSelector, PathSelector
from WebStack.Resources.Static import StringResource
import XSLForms.Resources.OpenIDLogin
from XSLForms.Resources.WebResources import output, prepare_resources as pr, resources

# Configuration settings.

encoding = "utf-8"

# Resource classes.

class LoginResource(XSLForms.Resources.OpenIDLogin.OpenIDLoginResource):

    "Special login screen for this application."

    resource_dir = resources(__file__)
    template_resources = {
        "login" : output("login_template.xhtml"),
        "success" : output("success_template.xhtml")
        }

# Site map initialisation.

def get_site(host, use_redirect=1):

    "Return a simple Web site resource."

    # Authentication objects.

    credentials = [
        ((host + "/badger", "badger"), "abc"),
        ((host + "/vole", "vole"), "xyz"),
        ((host + u"/", u""), u"")
        ]
    login_authenticator = Authenticator(credentials)

    # Get a login resource.

    login_resource = LoginResource(host, login_authenticator, use_redirect=use_redirect)

    # A container for the login resource and user pages.

    resource = MapResource({
        "login" : login_resource,

        # Some local OpenID pages.

        "badger" :
            StringResource("""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/badger" />
                    <title>Badger's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>badger</code>.</p>
                  </body>
                </html>
            """ % (host, host), ContentType("text/html")),
        u"" :
            StringResource(u"""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/" />
                    <title>Home Page for </title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code></code>.</p>
                  </body>
                </html>
            """ % (host, host), ContentType("text/html", "iso-8859-1")),
        "vole" :
            StringResource("""
                <html>
                  <head>
                    <link rel="openid2.provider openid.server" href="%s/login" />
                    <link rel="openid2.local_id openid.delegate" href="%s/vole" />
                    <title>Vole's Home Page</title>
                  </head>
                  <body>
                    <p>Home page for the OpenID authenticated user, <code>vole</code>.</p>
                  </body>
                </html>
            """ % (host, host), ContentType("text/html"))
        })

    # Wrap the resource up with information about the application root.

    return EncodingSelector(PathSelector(resource), encoding)

# Resource preparation ahead of time - useful for making installations.

def prepare_resources():
    for cls in [LoginResource]:
        pr(cls)

# vim: tabstop=4 expandtab shiftwidth=4
